@@ -10,6 +10,8 @@ from colorama import Fore, Style
 from engine.connections import Callisto, Europa, Neso
 from engine.libs.inquirer import select, confirm, filepath
 
+from .auth import login 
+
 
 @click.command()
 def projects():
@@ -30,6 +32,10 @@ def projects():
     print ()
     org = None
     if choose_public_private == "From my organization":
+        if not callisto.user:
+            print ("You are not logged in. Please login using " + Fore.CYAN + "engine login" + Style.RESET_ALL)
+            return
+
         orgs = callisto.get_orgs()
         org_choices = [Choice(org, name=org["name"]) for org in orgs]
         org = select(
@@ -68,9 +74,12 @@ def projects():
 
         if project["sensorIds"]:
             print (Fore.GREEN + "Sensors : " + Style.RESET_ALL, end="")
-            neso = Neso(callisto, None)
-            sensors = neso.get_sensors()
+            if org:
+                neso = Neso(callisto, org["id"])
+            else:
+                neso = Neso(callisto, None)
             sensor_ids = project['sensorIds']
+            sensors = neso.get_sensors()
             sensor_names = [sensors[sensor_id]["name"] for sensor_id in sensor_ids]
             print (Fore.GREEN + ', '.join(sensor_names) + Style.RESET_ALL)
 
@@ -123,14 +132,20 @@ def projects():
             )
         print ()
 
-        text = [("#F7F7F7", "Do you want to generate a experiment tracking configuration for ")]
+        text = [("#B5B7B4", "Do you want to generate a experiment tracking configuration for ")]
         if org:
             text += [("#3AB222", org['name']), ("#F7F7F7", "'s ")]
         text += [("#B4195D", project['name']),
-                ("#F7F7F7", " with "),
+                ("#B5B7B4", " with "),
                 ("#B29822", export['name']),
-                ("#F7F7F7", " export?")]
+                ("#B5B7B4", " export?")]
         color_print(text)
+        if not callisto.user:
+            print ()
+            print ("You are not logged in. Engine library requires your organization information to generate experiment tracking configuration.")
+            print ("Please login using " + Fore.CYAN + "engine login" + Style.RESET_ALL)
+            return
+
         want_config = confirm(message="", qmark="\U0001F913", amark="\U0001F913")
         print ()
 
