@@ -59,23 +59,34 @@ class Dione:
         assert self.org, "No org slug passed"
         assert projectId, "No projectId given"
 
-        get_experiment_url = f'{self.callisto.host}/dione/api/v1/experiments?orgId={self.org}&projectId={projectId}'
+        get_experiment_url = f'{self.callisto.host}/dione/api/v1/experiments?orgId={self.org}&projectId={projectId}&perPage=1000'
         response = requests.get(get_experiment_url, headers=self.callisto.headers)
 
         if response.status_code == 200:
             experiments = response.json()['results']
-            headers = ["ID", "ExportId", "Name", "Tags", "Status"]
-            table = [[experiment["id"], experiment["exportId"],
-                    experiment["name"], ','.join(experiment["tags"]), 
-                    experiment["status"]] for experiment in experiments]
 
-            print(f'\nList of experiments for GeoEngine project {projectId}:\n')
-            print(tabulate(table, headers=headers, tablefmt='pretty'))
-            print()
+            return experiments
         else:
             print(f'All experiments for GeoEngine project {projectId} cannot be retrieved')
             print(f'Experiments endpoint {get_experiment_url} returned with HTTP status code : {response.status_code}\n')
 
+            return None
+
+    def get_experiment_by_name(self, projectId, experiment_name):
+        assert self.org, "No org slug passed"
+        assert projectId, "No projectId given"
+        assert experiment_name, "No experiment name given"
+
+        get_experiment_url = f'{self.callisto.host}/dione/api/v1/experiments?orgId={self.org}&projectId={projectId}&experiment_name={experiment_name}'
+        response = requests.get(get_experiment_url, headers=self.callisto.headers)
+
+        if response.status_code == 200:
+            experiment = response.json()['results'][0]
+            return experiment
+        else:
+            print(f'Experiment {experiment_name} for GeoEngine project {projectId} cannot be retrieved')
+            print(f'Experiments endpoint {get_experiment_url} returned with HTTP status code : {response.status_code}\n')
+            return None
 
     def create_artifact(self, artifact):
         assert self.org, "No org slug passed"
