@@ -26,7 +26,7 @@ class Europa:
         return labels
 
     def get_image_details(self, id):
-        image_url = f'{self.callisto.host}/europa/api/v1/images/{id}'
+        image_url = f'{self.callisto.host}/europa/api/v2/projects/{id}'
 
         response = requests.get(image_url, headers=self.callisto.headers)
 
@@ -40,9 +40,9 @@ class Europa:
             
     def get_projects(self):
         if self.org:
-            get_project_url = f'{self.callisto.host}/europa/api/v1/tasks?orgId={self.org}'
+            get_project_url = f'{self.callisto.host}/europa/api/v2/projects?orgId={self.org}'
         else:
-            get_project_url = f"{self.callisto.host}/europa/api/v1/tasks?search=&status=all&isPublic=true"
+            get_project_url = f"{self.callisto.host}/europa/api/v2/projects?search=&status=all&isPublic=true"
         response = requests.get(get_project_url, headers=self.callisto.headers)
 
         if response.status_code == 200:
@@ -56,9 +56,9 @@ class Europa:
 
     def get_project_details(self, id, verbose=True):
         if self.org:
-            project_details_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}?orgId={self.org}'
+            project_details_url = f'{self.callisto.host}/europa/api/v2/projects/{id}?orgId={self.org}'
         else:
-            project_details_url = f"{self.callisto.host}/europa/api/v1/tasks/{id}?search=&status=all&isPublic=true"
+            project_details_url = f"{self.callisto.host}/europa/api/v2/projects/{id}?search=&status=all&isPublic=true"
 
         response = requests.get(project_details_url, headers=self.callisto.headers)
         
@@ -88,7 +88,7 @@ class Europa:
             return None 
             
     # def export_annotations(self, id):
-    #     export_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}/export'
+    #     export_url = f'{self.callisto.host}/europa/api/v2/projects/{id}/export'
 
     #     print(f'exporting annotations for task id : {id}')
 
@@ -104,9 +104,9 @@ class Europa:
     
     def get_project_exports(self, id):
         if self.org:
-            project_exports_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}/datasets?orgId={self.org}'
+            project_exports_url = f'{self.callisto.host}/europa/api/v2/projects/{id}/datasets?orgId={self.org}'
         else:
-            project_exports_url = f"{self.callisto.host}/europa/api/v1/tasks/{id}/datasets?search=&status=all&isPublic=true"
+            project_exports_url = f"{self.callisto.host}/europa/api/v2/projects/{id}/datasets?search=&status=all&isPublic=true"
 
         response = requests.get(project_exports_url, headers=self.callisto.headers)
         
